@@ -414,7 +414,7 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
         density_option = glade_xml_get_widget (xml, "density_option");
 	volume_name_entry = glade_xml_get_widget (xml, "volume_name_entry");
 
-	floppy.volume_name = gtk_entry_get_text (GTK_ENTRY (volume_name_entry));
+	floppy.volume_name = (gchar *) gtk_entry_get_text (GTK_ENTRY (volume_name_entry));
 
 	if (strstr (floppy.volume_name, " ")) {
 		GtkWidget *dialog;
@@ -450,9 +450,10 @@ on_format_button_clicked (GtkWidget *widget, gpointer user_data)
 int
 main (int argc, char *argv[])
 {
+	const GnomeIconData *icon_data;
+	gchar *icon_path = NULL;
 	GConfClient *client;
 	GFloppyConfig config;
-        GnomeIconData *icon_data;
         GnomeIconTheme *icon_theme;
 	GtkWidget *fs_entry;
 	GtkWidget *type_option;
